@@ -8,10 +8,6 @@ fi
 
 export PYAV_ROOT="$(cd "$(dirname "${BASH_SOURCE[0]}")/.."; pwd)"
 
-if [[ "$TRAVIS" ]]; then
-    PYAV_LIBRARY=$LIBRARY
-fi
-
 if [[ ! "$PYAV_LIBRARY" ]]; then
 
     # Pull from command line argument.
@@ -40,16 +36,11 @@ fi
 export PYAV_PYTHON
 export PYAV_PIP="${PYAV_PIP-$PYAV_PYTHON -m pip}"
 
-if [[ "$GITHUB_ACTION" || "$TRAVIS" ]]; then
+if [[ "$GITHUB_ACTION" ]]; then
 
-    # GitHub/Travis as a very self-contained environment. Lets just work in that.
+    # GitHub has a very self-contained environment. Lets just work in that.
     echo "We're on CI, so not setting up another virtualenv."
 
-    if [[ "$TRAVIS_PYTHON_VERSION" = "2.7" || "$TRAVIS_PYTHON_VERSION" = "pypy" ]]; then
-        PYAV_PYTHON=python
-        PYAV_PIP=pip
-    fi
-
 else
 
     export PYAV_VENV_NAME="$(uname -s).$(uname -r).$("$PYAV_PYTHON" -c '
