@@ -1,3 +1,5 @@
+from fractions import Fraction
+
 import av
 
 from .common import TestCase, fate_suite
@@ -51,7 +53,7 @@ class TestDecode(TestCase):
                 sample_count += frame.samples
 
         total_samples = (
-            audio_stream.duration * audio_stream.rate.numerator
+            audio_stream.duration * audio_stream.sample_rate.numerator
         ) / audio_stream.time_base.denominator
         self.assertEqual(sample_count, total_samples)
 
@@ -59,9 +61,8 @@ class TestDecode(TestCase):
 
         container = av.open(fate_suite("h264/interlaced_crop.mp4"))
         stream = container.streams.video[0]
-        codec_context = stream.codec_context
 
-        self.assertNotEqual(stream.time_base, codec_context.time_base)
+        self.assertEqual(stream.time_base, Fraction(1, 25))
 
         for packet in container.demux(stream):
             for frame in packet.decode():
