@@ -70,42 +70,73 @@ def assert_rgb_rotate(self, input_, is_dash=False):
     if is_dash:
         # FFmpeg 4.2 added parsing of the programme information and it is named "Title"
         if av.library_versions["libavformat"] >= (58, 28):
-            self.assertTrue(input_.metadata.get("Title") == "container", input_.metadata)
+            self.assertTrue(
+                input_.metadata.get("Title") == "container", input_.metadata
+            )
     else:
         self.assertEqual(input_.metadata.get("title"), "container", input_.metadata)
     self.assertEqual(input_.metadata.get("key"), None)
+
     stream = input_.streams[0]
-    self.assertIsInstance(stream, VideoStream)
-    self.assertEqual(stream.type, "video")
-    self.assertEqual(stream.name, "mpeg4")
-    self.assertEqual(
-        stream.average_rate, 24
-    )  # Only because we constructed is precisely.
-    self.assertEqual(stream.rate, Fraction(24, 1))
+
     if is_dash:
         # The DASH format doesn't provide a duration for the stream
         # and so the container duration (micro seconds) is checked instead
         self.assertEqual(input_.duration, 2000000)
+        expected_average_rate = 24
+        expected_duration = None
+        expected_frames = 0
+        expected_id = 0
     else:
-        self.assertEqual(stream.time_base * stream.duration, 2)
+        if av.library_versions["libavformat"] < (58, 76):
+            # FFmpeg < 4.4
+            expected_average_rate = Fraction(1152, 47)
+            expected_duration = 24064
+        else:
+            # FFmpeg >= 4.4
+            expected_average_rate = 24
+            expected_duration = 24576
+        expected_frames = 48
+        expected_id = 1
+
+    # actual stream properties
+    self.assertIsInstance(stream, VideoStream)
+    self.assertEqual(stream.average_rate, expected_average_rate)
+    self.assertEqual(stream.base_rate, 24)
+    self.assertEqual(stream.duration, expected_duration)
+    self.assertEqual(stream.guessed_rate, 24)
+    self.assertEqual(stream.frames, expected_frames)
+    self.assertEqual(stream.id, expected_id)
+    self.assertEqual(stream.index, 0)
+    self.assertEqual(stream.profile, "Simple Profile")
+    self.assertEqual(stream.start_time, 0)
+    self.assertEqual(stream.time_base, Fraction(1, 12288))
+    self.assertEqual(stream.type, "video")
+
+    # codec context properties
+    self.assertEqual(stream.codec.name, "mpeg4")
+    self.assertEqual(stream.codec.long_name, "MPEG-4 part 2")
     self.assertEqual(stream.format.name, "yuv420p")
     self.assertEqual(stream.format.width, WIDTH)
     self.assertEqual(stream.format.height, HEIGHT)
+    self.assertEqual(stream.ticks_per_frame, 1)
 
 
 class TestBasicVideoEncoding(TestCase):
     def test_default_options(self):
         with av.open(self.sandboxed("output.mov"), "w") as output:
             stream = output.add_stream("mpeg4")
+            self.assertEqual(stream.average_rate, Fraction(24, 1))
+            self.assertEqual(stream.time_base, None)
+
+            # codec context properties
             self.assertEqual(stream.bit_rate, 1024000)
             self.assertEqual(stream.format.height, 480)
             self.assertEqual(stream.format.name, "yuv420p")
             self.assertEqual(stream.format.width, 640)
             self.assertEqual(stream.height, 480)
             self.assertEqual(stream.pix_fmt, "yuv420p")
-            self.assertEqual(stream.rate, Fraction(24, 1))
             self.assertEqual(stream.ticks_per_frame, 1)
-            self.assertEqual(stream.time_base, None)
             self.assertEqual(stream.width, 640)
 
     def test_encoding(self):
@@ -151,11 +182,13 @@ class TestBasicAudioEncoding(TestCase):
     def test_default_options(self):
         with av.open(self.sandboxed("output.mov"), "w") as output:
             stream = output.add_stream("mp2")
+            self.assertEqual(stream.time_base, None)
+
+            # codec context properties
             self.assertEqual(stream.bit_rate, 128000)
             self.assertEqual(stream.format.name, "s16")
-            self.assertEqual(stream.rate, 48000)
+            self.assertEqual(stream.sample_rate, 48000)
             self.assertEqual(stream.ticks_per_frame, 1)
-            self.assertEqual(stream.time_base, None)
 
     def test_transcode(self):
         path = self.sandboxed("audio_transcode.mov")
@@ -197,9 +230,11 @@ class TestBasicAudioEncoding(TestCase):
 
             stream = container.streams[0]
             self.assertIsInstance(stream, AudioStream)
-            self.assertEqual(stream.codec_context.sample_rate, sample_rate)
-            self.assertEqual(stream.codec_context.format.name, "s16p")
-            self.assertEqual(stream.codec_context.channels, channels)
+
+            # codec context properties
+            self.assertEqual(stream.channels, channels)
+            self.assertEqual(stream.format.name, "s16p")
+            self.assertEqual(stream.sample_rate, sample_rate)
 
 
 class TestEncodeStreamSemantics(TestCase):
@@ -230,7 +265,7 @@ class TestEncodeStreamSemantics(TestCase):
                     # decoder didn't indicate constant frame size
                     frame_size = 1000
                 aframe = AudioFrame("s16", "stereo", samples=frame_size)
-                aframe.rate = 48000
+                aframe.sample_rate = 48000
                 apackets = astream.encode(aframe)
                 if apackets:
                     apacket = apackets[0]
