@@ -7,29 +7,28 @@ from .common import TestCase, is_windows
 
 
 class TestErrorBasics(TestCase):
-
     def test_stringify(self):
 
         for cls in (av.ValueError, av.FileNotFoundError, av.DecoderNotFoundError):
-            e = cls(1, 'foo')
-            self.assertEqual(str(e), '[Errno 1] foo')
+            e = cls(1, "foo")
+            self.assertEqual(str(e), "[Errno 1] foo")
             self.assertEqual(repr(e), "{}(1, 'foo')".format(cls.__name__))
             self.assertEqual(
                 traceback.format_exception_only(cls, e)[-1],
-                '{}{}: [Errno 1] foo\n'.format(
-                    'av.error.',
+                "{}{}: [Errno 1] foo\n".format(
+                    "av.error.",
                     cls.__name__,
                 ),
             )
 
         for cls in (av.ValueError, av.FileNotFoundError, av.DecoderNotFoundError):
-            e = cls(1, 'foo', 'bar.txt')
+            e = cls(1, "foo", "bar.txt")
             self.assertEqual(str(e), "[Errno 1] foo: 'bar.txt'")
             self.assertEqual(repr(e), "{}(1, 'foo', 'bar.txt')".format(cls.__name__))
             self.assertEqual(
                 traceback.format_exception_only(cls, e)[-1],
                 "{}{}: [Errno 1] foo: 'bar.txt'\n".format(
-                    'av.error.',
+                    "av.error.",
                     cls.__name__,
                 ),
             )
@@ -46,17 +45,19 @@ class TestErrorBasics(TestCase):
     def test_filenotfound(self):
         """Catch using builtin class on Python 3.3"""
         try:
-            av.open('does not exist')
+            av.open("does not exist")
         except FileNotFoundError as e:
             self.assertEqual(e.errno, errno.ENOENT)
             if is_windows:
-                self.assertTrue(e.strerror in ['Error number -2 occurred',
-                                               'No such file or directory'])
+                self.assertTrue(
+                    e.strerror
+                    in ["Error number -2 occurred", "No such file or directory"]
+                )
             else:
-                self.assertEqual(e.strerror, 'No such file or directory')
-            self.assertEqual(e.filename, 'does not exist')
+                self.assertEqual(e.strerror, "No such file or directory")
+            self.assertEqual(e.filename, "does not exist")
         else:
-            self.fail('no exception raised')
+            self.fail("no exception raised")
 
     def test_buffertoosmall(self):
         """Throw an exception from an enum."""
@@ -65,4 +66,4 @@ class TestErrorBasics(TestCase):
         except av.BufferTooSmallError as e:
             self.assertEqual(e.errno, av.error.BUFFER_TOO_SMALL.value)
         else:
-            self.fail('no exception raised')
+            self.fail("no exception raised")
