@@ -207,6 +207,112 @@ class TestVideoFrameNdarray(TestCase):
             self.assertEqual(frame.format.name, format)
             self.assertNdarraysEqual(frame.to_ndarray(), array)
 
+    def test_ndarray_gbrp(self):
+        array = numpy.random.randint(0, 256, size=(480, 640, 3), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format="gbrp")
+        self.assertEqual(frame.width, 640)
+        self.assertEqual(frame.height, 480)
+        self.assertEqual(frame.format.name, "gbrp")
+        self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp_align(self):
+        array = numpy.random.randint(0, 256, size=(238, 318, 3), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format="gbrp")
+        self.assertEqual(frame.width, 318)
+        self.assertEqual(frame.height, 238)
+        self.assertEqual(frame.format.name, "gbrp")
+        self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp10(self):
+        array = numpy.random.randint(0, 1024, size=(480, 640, 3), dtype=numpy.uint16)
+        for format in ["gbrp10be", "gbrp10le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 640)
+            self.assertEqual(frame.height, 480)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp10_align(self):
+        array = numpy.random.randint(0, 1024, size=(238, 318, 3), dtype=numpy.uint16)
+        for format in ["gbrp10be", "gbrp10le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp12(self):
+        array = numpy.random.randint(0, 4096, size=(480, 640, 3), dtype=numpy.uint16)
+        for format in ["gbrp12be", "gbrp12le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 640)
+            self.assertEqual(frame.height, 480)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp12_align(self):
+        array = numpy.random.randint(0, 4096, size=(238, 318, 3), dtype=numpy.uint16)
+        for format in ["gbrp12be", "gbrp12le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp14(self):
+        array = numpy.random.randint(0, 16384, size=(480, 640, 3), dtype=numpy.uint16)
+        for format in ["gbrp14be", "gbrp14le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 640)
+            self.assertEqual(frame.height, 480)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp14_align(self):
+        array = numpy.random.randint(0, 16384, size=(238, 318, 3), dtype=numpy.uint16)
+        for format in ["gbrp14be", "gbrp14le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp16(self):
+        array = numpy.random.randint(0, 65536, size=(480, 640, 3), dtype=numpy.uint16)
+        for format in ["gbrp16be", "gbrp16le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 640)
+            self.assertEqual(frame.height, 480)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrp16_align(self):
+        array = numpy.random.randint(0, 65536, size=(238, 318, 3), dtype=numpy.uint16)
+        for format in ["gbrp16be", "gbrp16le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrpf32(self):
+        array = numpy.random.random_sample(size=(480, 640, 3)).astype(numpy.float32)
+        for format in ["gbrpf32be", "gbrpf32le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 640)
+            self.assertEqual(frame.height, 480)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_gbrpf32_align(self):
+        array = numpy.random.random_sample(size=(238, 318, 3)).astype(numpy.float32)
+        for format in ["gbrpf32be", "gbrpf32le"]:
+            frame = VideoFrame.from_ndarray(array, format=format)
+            self.assertEqual(frame.width, 318)
+            self.assertEqual(frame.height, 238)
+            self.assertEqual(frame.format.name, format)
+            self.assertNdarraysEqual(frame.to_ndarray(), array)
+
     def test_ndarray_yuv420p(self):
         array = numpy.random.randint(0, 256, size=(720, 640), dtype=numpy.uint8)
         frame = VideoFrame.from_ndarray(array, format="yuv420p")
@@ -291,6 +397,17 @@ class TestVideoFrameNdarray(TestCase):
         # check endianness by examining red value of first pixel
         self.assertPixelValue16(frame.planes[0], array[0][0][0], "little")
 
+    def test_ndarray_rgb48le_align(self):
+        array = numpy.random.randint(0, 65536, size=(238, 318, 3), dtype=numpy.uint16)
+        frame = VideoFrame.from_ndarray(array, format="rgb48le")
+        self.assertEqual(frame.width, 318)
+        self.assertEqual(frame.height, 238)
+        self.assertEqual(frame.format.name, "rgb48le")
+        self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+        # check endianness by examining red value of first pixel
+        self.assertPixelValue16(frame.planes[0], array[0][0][0], "little")
+
     def test_ndarray_rgba64be(self):
         array = numpy.random.randint(0, 65536, size=(480, 640, 4), dtype=numpy.uint16)
         frame = VideoFrame.from_ndarray(array, format="rgba64be")
@@ -341,6 +458,22 @@ class TestVideoFrameNdarray(TestCase):
         self.assertNdarraysEqual(returned[0], array)
         self.assertNdarraysEqual(returned[1], palette)
 
+    def test_ndarray_nv12(self):
+        array = numpy.random.randint(0, 256, size=(720, 640), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format="nv12")
+        self.assertEqual(frame.width, 640)
+        self.assertEqual(frame.height, 480)
+        self.assertEqual(frame.format.name, "nv12")
+        self.assertNdarraysEqual(frame.to_ndarray(), array)
+
+    def test_ndarray_nv12_align(self):
+        array = numpy.random.randint(0, 256, size=(357, 318), dtype=numpy.uint8)
+        frame = VideoFrame.from_ndarray(array, format="nv12")
+        self.assertEqual(frame.width, 318)
+        self.assertEqual(frame.height, 238)
+        self.assertEqual(frame.format.name, "nv12")
+        self.assertNdarraysEqual(frame.to_ndarray(), array)
+
 
 class TestVideoFrameTiming(TestCase):
     def test_reformat_pts(self):
